instrumenttools.Bassoon
=======================

.. abjad-lineage:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon

.. autoclass:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Bassoon.Bassoon.Bassoon.__repr__
   :noindex:
